==============================================
Coding Guidelines & Standartisized Dataformats
==============================================

Coding Guidelines
=================

We offfer a set of generic coding Guidelines.

 * `Generic Development Guidelines <http://github.com/hudora/huTools/blob/master/doc/development.markdown#readme>`_
 * `How to construct commandline tools <http://github.com/hudora/huTools/blob/master/doc/commandline_tools.markdown#readme>`_
 * `How to construct User Interfaces <http://github.com/hudora/huTools/blob/master/doc/userinterfaces.markdown#readme>`_
 
 
Standards / Protocols
=====================

We offer a set of guidelines how to structure Data for certain applications. 

 * `AddressProtocol <http://github.com/hudora/huTools/blob/master/doc/standards/address_protocol.markdown#readme>`_ for structured exchange of (postal) Adresses.
 * `LieferungProtocol <http://github.com/hudora/huTools/blob/master/doc/standards/lieferungprotocol.markdown#readme>`_ for delivery notes, packing orders etc.
 * `VerySimpleOrderProtocol <http://github.com/hudora/huTools/blob/master/doc/standards/verysimpleorderprotocol.markdown#readme>`_ for purchase orders
 * `VerySimpleStatusProtocol <http://github.com/hudora/huTools/blob/master/doc/standards/verysimplestatusprotocol.markdown#readme>`_ for track & trace information
 * `Artikelstammdaten <http://github.com/hudora/huTools/blob/master/doc/standards/artikelstammdaten.markdown#readme>`_ for basic product data
 * `Messaging/Transport <http://github.com/hudora/huTools/blob/master/doc/standards/messaging_transport.markdown#readme>`_ for transporting over messaging system
 * `Messaging IC/WMS <http://github.com/hudora/huTools/blob/master/doc/standards/messaging_ic-wms.markdown#readme>`_ for messaging between an ERV System and an Warehouse Managment System
 * `Messaging WMS=Logos <http://github.com/hudora/huTools/blob/master/doc/standards/WMS%3DLogos.markdown#readme>`_ Implementation Notes for the Warehouse Managment System "Logos".
 